@@ -111,6 +111,12 @@ pub enum Commands {
         #[command(subcommand)]
         format: Option<SbomCommand>,
     },
+    /// Manage cache
+    Cache {
+        /// Clear the GitHub licenses cache
+        #[arg(long)]
+        clear: bool,
+    },
 }
 
 #[derive(Parser, Debug, Clone)]
@@ -150,6 +156,10 @@ pub struct Cli {
     #[arg(long)]
     pub ssh_passphrase: Option<String>,
 
+    /// GitHub personal access token for API authentication (increases rate limits)
+    #[arg(long, env = "GITHUB_TOKEN", global = true)]
+    pub github_token: Option<String>,
+
     /// Output in JSON format
     #[arg(long, short, group = "output")]
     /// This will override the default output format
@@ -455,6 +465,7 @@ mod tests {
             token: None,
             ssh_key: None,
             ssh_passphrase: None,
+            github_token: None,
             json: false,
             yaml: false,
             verbose: false,
@@ -479,6 +490,7 @@ mod tests {
         assert!(!cli.restrictive);
         assert!(!cli.strict);
         assert!(!cli.no_local);
+        assert!(cli.github_token.is_none());
         assert!(cli.is_default_command());
     }
 
@@ -496,6 +508,7 @@ mod tests {
             token: None,
             ssh_key: None,
             ssh_passphrase: None,
+            github_token: None,
             json: false,
             yaml: false,
             verbose: false,
@@ -528,6 +541,9 @@ mod tests {
             Commands::Sbom { .. } => {
                 panic!("Expected Generate command");
             }
+            Commands::Cache { .. } => {
+                panic!("Expected Generate command");
+            }
         }
         assert!(!cli.is_default_command());
     }
@@ -542,6 +558,7 @@ mod tests {
             token: None,
             ssh_key: None,
             ssh_passphrase: None,
+            github_token: None,
             json: false,
             yaml: false,
             verbose: false,
@@ -574,6 +591,9 @@ mod tests {
             Commands::Sbom { .. } => {
                 panic!("Expected Generate command");
             }
+            Commands::Cache { .. } => {
+                panic!("Expected Generate command");
+            }
         }
     }
 
